Nets
====

Classes
-------

.. currentmodule:: ansys.edb.core.net

.. autosummary::
   :toctree: _autosummary

   differential_pair.DifferentialPair
   extended_net.ExtendedNet
   net.Net
   net_class.NetClass
